<?php

/*
Plugin Name: Article Manager
Description: News Manager clone
Version: 3.0 beta
Original author: Rogier Koppejan
Updated by: Carlos Navarro

*/

# plugin version
define('AMVERSION', '3.0 beta');

# get correct id for plugin
$thisfile = basename(__FILE__, '.php');

# register plugin
register_plugin(
  $thisfile,
  'Article Manager',
  AMVERSION,
  'Rogier Koppejan, Carlos Navarro',
  'http://newsmanager.c1b.org/',
  'News Manager clone',
  'pages',
  'am_admin'
);

# includes
require_once(GSPLUGINPATH.'article_manager/inc/common.php');

# language
i18n_merge('article_manager') || i18n_merge('article_manager', 'en_US');

# hooks
add_action('pages-sidebar', 'createSideMenu', array($thisfile, i18n_r('article_manager/PLUGIN_NAME')));
add_action('header', 'am_header_include');
add_action('index-pretemplate', 'am_frontend_init');
add_action('theme-header','am_restore_page_title');
//add_filter('content', 'am_site'); // deprecated
if (!function_exists('generate_sitemap')) {
  add_action('sitemap-additem', 'am_sitemap_include'); // GetSimple 3.0
} else {
  add_filter('sitemap','am_update_sitemap_xml'); // for GetSimple 3.3+
}
/*if (!defined('AMNOAPIUPDATE') || !AMNOAPIUPDATE) {
  add_action('common', 'am_update_extend_cache');
}*/

# scripts (GetSimple 3.1+)
if (function_exists('register_script')) {
  if (isset($_GET['id']) && $_GET['id'] == 'article_manager' && (isset($_GET['edit']) || isset($_GET['settings']))) {
    if (!defined('GSNOCDN') || !GSNOCDN) {
      register_script('jquery-validate','//ajax.aspnetcdn.com/ajax/jquery.validate/1.10.0/jquery.validate.min.js', '1.10.0', false);
    } else {
      register_script('jquery-validate',$SITEURL.'plugins/article_manager/js/jquery.validate.min.js', '1.10.0', false);
    }
    queue_script('jquery-validate', GSBACK);
  }
}

/*******************************************************
 * @function am_admin
 * @action back-end main function
 */
function am_admin() {
  if (am_env_check()) {
    # post management
    if (isset($_GET['edit'])) {
        am_edit_post($_GET['edit']);
    } elseif (isset($_POST['post'])) {
        am_save_post();
        am_admin_panel();
    } elseif (isset($_GET['delete'])) {
        am_delete_post($_GET['delete']);
        am_admin_panel();
    } elseif (isset($_GET['restore'])) {
        am_restore_post($_GET['restore']);
        am_admin_panel();
    # settings management
    } elseif (isset($_GET['settings'])) {
        am_edit_settings();
    } elseif (isset($_POST['settings'])) {
        am_save_settings();
        am_admin_panel();
    } elseif (isset($_GET['htaccess'])) {
        am_generate_htaccess();
    } else {
        am_admin_panel();
    }
  }
}

/*******************************************************
 * @function am_frontend_init
 * @action front-end main function
 * @since 2.4
 */
function am_frontend_init() {
  global $AMPAGEURL, $ampagetype;
  $ampagetype = array();
  am_i18n_merge();
  $url = strval(get_page_slug(false));
  if ($url == $AMPAGEURL) {
    global $content, $metad;
    $metad_orig = ($metad == '' ? ' ' : $metad);
    $metad = ' ';
    $ampagetype[] = 'site';
    ob_start();
    echo PHP_EOL;
    if (isset($_POST['search'])) {
        am_reset_options('search');
        am_show_search_results();
        $ampagetype[] = 'search';

    } elseif (isset($_GET[AMPARAMARCHIVE])) {
        am_reset_options('archive');
        if (am_show_archive($_GET[AMPARAMARCHIVE], false))
          $ampagetype[] = 'archive';

    } elseif (isset($_GET[AMPARAMTAG])) {
        am_reset_options('tag');
        if (am_get_option('tagpagination')) {
          $index = isset($_GET[AMPARAMPAGE]) ? intval($_GET[AMPARAMPAGE]) : AMFIRSTPAGE;
          if (am_show_tag_page(rawurldecode($_GET[AMPARAMTAG]), $index, false))
            $ampagetype[] = 'tag';
        } else {
          if (am_show_tag(rawurldecode($_GET[AMPARAMTAG]), false))
            $ampagetype[] = 'tag';
        }

    } elseif (isset($_GET[AMPARAMPOST])) {
        am_reset_options('single');
        if (am_show_post($_GET[AMPARAMPOST], false, false, true))
          $ampagetype[] = 'single';

    } elseif (isset($_GET[AMPARAMPAGE]) && intval($_GET[AMPARAMPAGE]) > AMFIRSTPAGE) {
        am_reset_options('main');
        am_show_page($_GET[AMPARAMPAGE], false);
        $ampagetype[] = 'main';

    } else {
        $metad = $metad_orig;
        am_reset_options('main');
        am_show_page(AMFIRSTPAGE, false);
        array_push($ampagetype, 'main', 'home');
    }
    $content = am_ob_get_content(false);
    $content = addslashes(htmlspecialchars($content, ENT_QUOTES, 'UTF-8'));
  }
  if (am_get_option('templatefile'))
    am_switch_template_file(am_get_option('templatefile'));
  am_reset_options();
  am_update_page_title();
}

/*******************************************************
 * @deprecated as of 2.4+
 */
function am_site($content) {
  return '[deprecated]';
}
