<?php if (!defined('IN_GS')) {die('you cannot load this page directly.');}

/**
 * Article Manager general functions.
 */


/*******************************************************
 * @function am_get_posts
 * @param $all if true, include private and future posts
 * @return array with posts
 */
function am_get_posts($all=false) {
  if (!file_exists(AMPOSTCACHE))
    am_update_cache();
  $data = @getXML(AMPOSTCACHE);
  $now = time();
  $posts = array();
  foreach ($data->item as $item) {
    if ($all || $item->private != 'Y' && strtotime($item->date) < $now)
      $posts[] = $item;
  }
  return $posts;
}


/*******************************************************
 * @function am_get_archives
 * @return array with monthly or yearly archives (keys) and post slugs (values)
 * @param $by month ('m') or year ('y'), default 'm' for monthly archives
 */
function am_get_archives($by='m') {
  $archives = array();
  $posts = am_get_posts();
  $datefmt = ($by == 'y') ? 'Y' : 'Ym';
  foreach ($posts as $post) {
    $archive = date($datefmt, strtotime($post->date));
    $archives[$archive][] = $post->slug;
  }
  return $archives;
}


/*******************************************************
 * @function am_get_tags
 * @return array with unique tags (keys) and posts (values)
 */
function am_get_tags() {
  $tags = array();
  $posts = am_get_posts();
  foreach ($posts as $post) {
    if (!empty($post->tags)) {
      foreach (explode(',', am_lowercase_tags(strip_decode($post->tags))) as $tag)
        $tags[trim($tag)][] = $post->slug;
    }
  }
  ksort($tags);
  return $tags;
}


/*******************************************************
 * @function am_get_languages
 * @return array with language files in AMLANGPATH
 */
function am_get_languages() {
  $languages = array();
  $files = getFiles(AMLANGPATH);
  foreach ($files as $file) {
    if (isFile($file, AMLANGPATH, 'php')) {
      $lang = basename($file, '.php');
      $languages[$lang] = AMLANGPATH . $file;
    }
  }
  ksort($languages);
  return $languages;
}


/*******************************************************
 * @function am_get_date
 * @param $format date format
 * @param $timestamp UNIX timestamp
 * @return date formatted according to $AMLANG
 */
function am_get_date($format, $timestamp) {
  global $AMLANG, $i18n;
  $locale = setlocale(LC_TIME, 0);
  // setlocale(LC_TIME, $AMLANG);
  if (array_key_exists('article_manager/LOCALE', $i18n)) {
    setlocale(LC_TIME, preg_split('/s*,s*/', $i18n['article_manager/LOCALE']));
  } else {
    # no locale in language file
    $lg = substr($AMLANG,0,2);
    setlocale(LC_TIME, $AMLANG.'.utf8', $lg.'.utf8', $AMLANG.'.UTF-8', $lg.'.UTF-8', $AMLANG, $lg);
  }
  if (strtoupper(substr(PHP_OS, 0, 3)) == 'WIN') {
    # fixes for Windows
    $format = preg_replace('#(?<!%)((?:%%)*)%e#', '\1%#d', $format); // strftime %e parameter not supported
    $date = utf8_encode(strftime($format, $timestamp)); // strftime returns ISO-8859-1 encoded string
  } else {
    $date = strftime($format, $timestamp);
  }
  setlocale(LC_TIME, $locale);
  return $date;
}


/*******************************************************
 * @function am_get_url
 * @return url of front-end newspage, with optional query
 */
function am_get_url($query=false) {
  global $PRETTYURLS, $AMPAGEURL, $AMPRETTYURLS;
  $str = '';
  $url = find_url($AMPAGEURL, am_get_parent());
  if (basename($_SERVER['PHP_SELF']) != 'index.php') // back end only
    if (function_exists('find_i18n_url')) // I18N?
      $url = find_i18n_url($AMPAGEURL, am_get_parent(), return_i18n_default_language());
  if ($query) {
    switch($query) {
      case 'post':
        $query = AMPARAMPOST;
        break;
      case 'page':
        $query = AMPARAMPAGE;
        break;
      case 'tag':
        $query = AMPARAMTAG;
        break;
      case 'archive':
        $query = AMPARAMARCHIVE;
        break;
    }
    if ($PRETTYURLS == 1 && $AMPRETTYURLS == 'Y') {
      if ($query == AMPARAMPOST && defined('AMNOPARAMPOST') && AMNOPARAMPOST)
        $str = '';
      else
        $str = $query . '/';
      if (substr($url, -1) != '/')
        $str = '/' . $str;
    } else {
      $str = (strpos($url,'?') === false)? '?' : '&amp;';
      $str .= $query.'=';
    }
  }
  return $url . $str;
}

/*******************************************************
 * @function am_get_parent
 * @return front-end newspage's parent slug
 * @since 2.4.0
 */
function am_get_parent() {
  global $AMPARENTURL, $AMPAGEURL;
  if ($AMPAGEURL == '') {
    $AMPARENTURL = '';
  } else {
    if ($AMPARENTURL == '?') {
      global $pagesArray;
      if ($pagesArray) {
        $AMPARENTURL = returnPageField($AMPAGEURL, 'parent');
      } else {
        $gsdata = getXML(GSDATAPAGESPATH.$AMPAGEURL.'.xml');
        $AMPARENTURL = isset($gsdata->parent) ? $gsdata->parent : '';
      }
    }
  }
  return $AMPARENTURL;
}

/*******************************************************
 * @function am_get_image_url
 * @param $pic image URL, full or relative to data/uploads/
 * @return absolute URL of thumbnail/image as defined by $amoption settings
 * @since 3.0
 */
function am_get_image_url($pic, $width=null, $height=null, $crop=null, $default=null) {
  global $SITEURL, $amoption;
  $url = '';
  if (empty($pic)) {
    if ($default)
      $pic = $default;
    else
      if ($default !== '' && $amoption['imagedefault'])
        $pic = $amoption['imagedefault'];
  }
  if (!empty($pic)) {
    if (!isset($width)) $width = $amoption['imagewidth'];
    if (!isset($height)) $height = $amoption['imageheight'];
    if (!isset($crop)) $crop = $amoption['imagecrop'];
    $pos = strpos($pic, 'data/uploads/');
    if ($pos !== false || strpos($pic, '/data/thumbs/') !== false || !strpos($pic, '://')) {
      if ($pos !== false) $pic = substr($pic, $pos+13);
      $w = $width ? '&w='.$width : '';
      $h = $height ? '&h='.$height : '';
      $c = $crop ? '&c=1' : '';
      $url = $SITEURL.'plugins/article_manager/browser/pic.php?p='.$pic.$w.$h.$c;
    } else {
      if ($amoption['imageexternal'])
        $url = $pic;
    }
  }
  return $url;
}

/*******************************************************
 * @function am_create_dir
 * @param $path full path of the directory
 * @action create the directory $path
 */
function am_create_dir($path) {
  if (mkdir($path, 0777)) {
    $fh = fopen($path . '.htaccess', 'w');
    fwrite($fh, 'Deny from all');
    fclose($fh);
    return true;
  }
  return false;
}

/*******************************************************
 * @function am_rename_file
 * @since 2.3.2
 * @param $oldfile origin file
 * @param $newfile destination file
 * @action rename or move a file - like rename() but safer (Windows)
 * @link http://www.php.net/manual/en/function.rename.php#56576
 */
function am_rename_file($oldfile,$newfile) {
  if (!rename($oldfile,$newfile)) {
    if (copy ($oldfile,$newfile)) {
      unlink($oldfile);
      return TRUE;
    }
    return FALSE;
  }
  return TRUE;
}

/*******************************************************
 * @function am_create_slug
 * @param $str string
 * @return a url friendly version of $str
 */
function am_create_slug($str) {
  global $i18n;
  $str = trim($str);
  if (isset($i18n['TRANSLITERATION']) && is_array($translit=$i18n['TRANSLITERATION']) && count($translit>0)) {
    $str = str_replace(array_keys($translit),array_values($translit),$str);
  }
  $str = to7bit($str, 'UTF-8');
  $str = clean_url($str);
  return $str;
}


/*******************************************************
 * @function am_create_excerpt
 * @param $content the post content
 * @param $url if not FALSE, URL to add "read more" link
 * @param $forcereadmore always add "read more" link, even if not truncated
 * @return a truncated version of the post content
 */
function am_create_excerpt($content, $url=false, $forcereadmore=false) {
  global $AMEXCERPTLENGTH;
  $len = intval($AMEXCERPTLENGTH);
  if ($len == 0) {
    return '';
  } else {
    $ellipsis = i18n_r('article_manager/ELLIPSIS');
    $break = am_get_option('breakwords');
    if ($url) {
      $readmorehtml = '<span class="am_readmore"><a href="'.$url.'">'.i18n_r('article_manager/READ_MORE').'</a></span>';
      if ($forcereadmore)
        $content = am_make_excerpt($content, $len, $ellipsis, $break).' '.$readmorehtml;
      else
        $content = am_make_excerpt($content, $len, $ellipsis.$readmorehtml, $break);
    } else {
      $content = am_make_excerpt($content, $len, $ellipsis, $break);
    }
    return '<p>'.$content.'</p>';
  }
}


/*******************************************************
 * @function am_make_excerpt
 * @param $content source string (html/text)
 * @param $len maximum excerpt length
 * @param $ellipsis optional string to be appended at the end (e.g. '...')
 * @param $break allow cutting off last word
 * @return excerpt without html tags and usual GS placeholders
 * @since 3.0
 */
function am_make_excerpt($content, $len=200, $ellipsis='', $break=false) {
  $content = preg_replace('/\(%.*?%\)/', '', $content); // remove (% ... %)
  $content = preg_replace('/\{%.*?%\}/', '', $content); // remove {% ... %}
  $content = strip_tags($content);
  $content = preg_replace('/\s+/u', ' ', str_replace('&nbsp;', ' ', $content)); // remove whitespace
  if (function_exists('mb_strlen')) {
    if (mb_strlen($content, 'UTF-8') > $len) {
      if ($break)
        $content = mb_substr($content, 0, $len, 'UTF-8');
      else
        $content = mb_substr($content, 0, mb_strrpos(mb_substr($content, 0, $len+1, 'UTF-8'), ' ', 'UTF-8'), 'UTF-8');
      $content .= $ellipsis;
    }
  } else {
    if (strlen($content) > $len) {
      if ($break)
        $content = substr($content, 0, $len);
      else
        $content = substr($content, 0, strrpos(substr($content, 0, $len+1), ' '));
      $content .= $ellipsis;
    }
  }
  return $content;
}

/*******************************************************
 * @function am_i18n_merge
 * @action update the $i18n language array (frontend)
 */
function am_i18n_merge() {
  global $AMLANG;
  if (isset($AMLANG) && $AMLANG != '') {
    if (dirname(realpath(AMLANGPATH.$AMLANG.'.php')) != realpath(AMLANGPATH)) die(''); // path traversal
    include(AMLANGPATH.$AMLANG.'.php');
    global $am_i18n;
    if ($am_i18n) {
      $am_i18n = array_merge($i18n, $am_i18n); // merge custom array
    } else {
      $am_i18n = $i18n;
    }
    global $i18n;
    foreach ($am_i18n as $code=>$text)
      $i18n['article_manager/' . $code] = $text;
  }
}


/*******************************************************
 * @function am_sitemap_include
 * @action add posts to sitemap.xml, for GetSimple 3.0 only
 */
function am_sitemap_include() {
  global $AMPAGEURL, $page, $xml;
  if (strval($page['url']) == $AMPAGEURL) {
    $posts = am_get_posts();
    foreach ($posts as $post) {
      $url = am_get_url('post').$post->slug;
      $file = AMPOSTPATH.$post->slug.'.xml';
      $date = makeIso8601TimeStamp(date('Y-m-d H:i:s', filemtime($file)));
      $item = $xml->addChild('url');
      $item->addChild('loc', $url);
      $item->addChild('lastmod', $date);
      $item->addChild('changefreq', 'monthly');
      $item->addChild('priority', '0.5');
    }
  }
}


/*******************************************************
 * @function am_header_include
 * @action insert necessary script/style sections into site header
 */
function am_header_include() {
  if (isset($_GET['id']) && $_GET['id'] == 'article_manager' && (isset($_GET['edit']) || isset($_GET['settings']))) {
    if (!function_exists('register_script')) {
      // for GetSimple 3.0
      echo '<script type="text/javascript" src="//ajax.aspnetcdn.com/ajax/jquery.validate/1.10.0/jquery.validate.min.js"></script>';
    }
  ?>
  <style>
    .invalid {
      color: #D94136;
      font-size: 11px;
      font-weight: normal;
    }
  </style>
  <?php
  }
}


/*******************************************************
 * @function am_display_message
 * @param $msg a string containing the message
 * @param $error if true, show as $msg as error, else as update
 * @param $backup when set, include undo link
 * @action display status messages on back-end pages
 */
function am_display_message($msg, $error=false, $backup=null) {
  if (isset($msg)) {
    if (isset($backup))
      $msg .= ' <a href="load.php?id=article_manager&amp;restore='.$backup.'">'.i18n_r('UNDO').'</a>';
    ?>
    <script type="text/javascript">
      $(function() {
        $('div.bodycontent').before('<div class="<?php echo $error ? 'error' : 'updated'; ?>" style="display:block;">'+
          <?php echo json_encode($msg); ?>+'</div>');
        $(".updated, .error").fadeOut(500).fadeIn(500);
      });
    </script>
    <noscript>
      <div class="<?php echo $error ? 'error' : 'updated'; ?>" style="display:block;"><?php echo $msg; ?></div>
    </noscript>
    <?php
  }
}


/*******************************************************
 * @function am_lowercase_tags
 * @param $str a string containing post tags
 * @action convert string to lowercase if "lowercasetags" enabled
 * @since 3.0
 */
function am_lowercase_tags($str) {
  if (defined('AMLOWERCASETAGS') && AMLOWERCASETAGS)
    return lowercase($str);
  else
    return $str;
}

/*******************************************************
 * @function am_generate_sitemap
 * @action trigger Sitemap update only if GetSimple 3.3+
 * @since 2.5
 */
function am_generate_sitemap() {
  if (GSVERSION >= '3.3' && (!defined('AMNOSITEMAP') || !AMNOSITEMAP))
    generate_sitemap();
}

/*******************************************************
 * @function am_update_sitemap_xml
 * @action add posts to sitemap.xml, GetSimple 3.3+
 * @param xmlobj
 * @since 2.5
 */
function am_update_sitemap_xml($xml) {
  if (!defined('AMNOSITEMAP') || !AMNOSITEMAP) {
    $posts = am_get_posts();
    foreach ($posts as $post) {
      $url = am_get_url('post').$post->slug;
      $file = AMPOSTPATH.$post->slug.'.xml';
      $date = makeIso8601TimeStamp(date('Y-m-d H:i:s', strtotime($post->date)));
      $item = $xml->addChild('url');
      $item->addChild('loc', $url);
      $item->addChild('lastmod', $date);
      $item->addChild('changefreq', 'monthly');
      $item->addChild('priority', '0.5');
    }
  }
  return $xml;
}

/*******************************************************
 * @function am_update_extend_cache
 * @action hack to replace Extend API cache file
 * @uses $site_link_back_url (GetSimple's configuration.php)
 * @since 3.0
 */
/*function am_update_extend_cache() {
  if (!is_frontend() && get_filename_id() == 'plugins') {
    include(GSADMININCPATH.'configuration.php');
    $url = $site_link_back_url.'api/extend/?id=541';
    $tempfile = GSCACHEPATH.md5($url).'.txt';
    $cachefile = GSCACHEPATH.md5($site_link_back_url.'api/extend/?file=article_manager.php').'.txt';
    get_api_details('custom', $url);
    if (file_exists($cachefile)) unlink($cachefile);
    @copy($tempfile, $cachefile);
  }
}*/

# since 3.0
# for templateFile custom setting (may be renamed later)
function am_switch_template_file($tempfile) {
  global $template_file, $TEMPLATE;
  $tempfile = am_get_option('templatefile');
  # no path traversal and template exists
  if (strpos(realpath(GSTHEMESPATH.$TEMPLATE."/".$tempfile), realpath(GSTHEMESPATH.$TEMPLATE."/")) === 0 && file_exists(GSTHEMESPATH.$TEMPLATE."/".$tempfile))
    $template_file = $tempfile;
}

?>