<?php if (!defined('IN_GS')) {die('you cannot load this page directly.');}

/**
 * Article Manager configuration functions.
 */


/*******************************************************
 * @function am_env_check
 * @action check plugin enviroament
 */
function am_env_check() {
  $env_ok = file_exists(AMPOSTPATH) || am_create_dir(AMPOSTPATH);
  if ($env_ok && !file_exists(AMBACKUPPATH))
    $env_ok = am_create_dir(AMBACKUPPATH);
  if ($env_ok && !file_exists(AMDATAPATH)) {
    if ($env_ok = am_create_dir(AMDATAPATH))
      am_update_cache();
  }
  if (!$env_ok)
    echo '<h3>Article Manager</h3><p>' . i18n_r('article_manager/ERROR_ENV') . '</p>';
  return $env_ok;
}


/*******************************************************
 * @function am_edit_settings
 * @action edit plugin configuration settings
 */
function am_edit_settings() {
  global $PRETTYURLS, $PERMALINK, $AMPAGEURL, $AMPRETTYURLS, $AMLANG, $AMSHOWEXCERPT,
         $AMEXCERPTLENGTH, $AMPOSTSPERPAGE, $AMRECENTPOSTS, $AMSETTING;
  include(AMTEMPLATEPATH . 'edit_settings.php');
}


/*******************************************************
 * @function am_save_settings
 * @action parse POST data and save to config file
 */
function am_save_settings() {
  global $AMPAGEURL, $AMPRETTYURLS, $AMLANG, $AMSHOWEXCERPT, $AMEXCERPTLENGTH,
         $AMPOSTSPERPAGE, $AMRECENTPOSTS, $AMSETTING;
  $backup = array('page_url' => $AMPAGEURL, 'pretty_urls' => $AMPRETTYURLS);
  # parse $_POST
  $AMPAGEURL       = $_POST['page-url'];
  $AMPRETTYURLS    = isset($_POST['pretty-urls']) ? 'Y' : '';
  $AMLANG          = $_POST['language'];
  $AMSHOWEXCERPT   = $_POST['show-excerpt'] ? 'Y' : '';
  $AMEXCERPTLENGTH = intval($_POST['excerpt-length']);
  $AMPOSTSPERPAGE  = intval($_POST['posts-per-page']);
  $AMRECENTPOSTS   = intval($_POST['recent-posts']);
  # new settings since 3.0
  $AMSETTING = array();
  $AMSETTING['archivesby'] = $_POST['archivesby'];
  $AMSETTING['readmore'] = $_POST['readmore'];
  $AMSETTING['titlelink'] = $_POST['titlelink'];
  $AMSETTING['gobacklink'] = $_POST['gobacklink'];
  $AMSETTING['images'] = $_POST['images'];
  $AMSETTING['imagewidth'] = $_POST['imagewidth'];
  $AMSETTING['imageheight'] = $_POST['imageheight'];
  $AMSETTING['imagecrop'] = isset($_POST['imagecrop']);
  $AMSETTING['imagealt'] = isset($_POST['imagealt']);
  $AMSETTING['imagelink'] = isset($_POST['imagelink']);
  $AMSETTING['enablecustomsettings'] = isset($_POST['enablecustomsettings']);
  $AMSETTING['customsettings'] = $_POST['customsettings'];
  # write settings to file
  if (am_settings_to_xml()) {
    am_generate_sitemap();
    am_display_message(i18n_r('article_manager/SUCCESS_SAVE'));
  } else {
    am_display_message(i18n_r('article_manager/ERROR_SAVE'), true);
  }
  # should we update .htaccess?
  if ($AMPRETTYURLS == 'Y') {
    if ($backup['pretty_urls'] != 'Y' || $backup['page_url'] != $AMPAGEURL)
      am_display_message(sprintf(i18n_r('article_manager/UPDATE_HTACCESS'), 'load.php?id=article_manager&amp;htaccess'), true);
  }
}


/*******************************************************
 * @function am_settings_to_xml
 * @action write plugin settings to config file
 */
function am_settings_to_xml() {
  global $AMPAGEURL, $AMPRETTYURLS, $AMLANG, $AMSHOWEXCERPT, $AMEXCERPTLENGTH,
         $AMPOSTSPERPAGE, $AMRECENTPOSTS, $AMSETTING;
  $xml = new SimpleXMLExtended('<?xml version="1.0" encoding="UTF-8"?><item></item>');
  $obj = $xml->addChild('page_url', $AMPAGEURL);
  $obj = $xml->addChild('pretty_urls', $AMPRETTYURLS);
  $obj = $xml->addChild('language', $AMLANG);
  $obj = $xml->addChild('show_excerpt', $AMSHOWEXCERPT);
  $obj = $xml->addChild('excerpt_length', $AMEXCERPTLENGTH);
  $obj = $xml->addChild('posts_per_page', $AMPOSTSPERPAGE);
  $obj = $xml->addChild('recent_posts', $AMRECENTPOSTS);
  $obj = $xml->addChild('archivesby', $AMSETTING['archivesby']);
  $obj = $xml->addChild('readmore', $AMSETTING['readmore']);
  $obj = $xml->addChild('titlelink', $AMSETTING['titlelink']);
  $obj = $xml->addChild('gobacklink', $AMSETTING['gobacklink']);
  $obj = $xml->addChild('images', $AMSETTING['images']);
  $obj = $xml->addChild('imagewidth', $AMSETTING['imagewidth']);
  $obj = $xml->addChild('imageheight', $AMSETTING['imageheight']);
  $obj = $xml->addChild('imagecrop', $AMSETTING['imagecrop']);
  $obj = $xml->addChild('imagealt', $AMSETTING['imagealt']);
  $obj = $xml->addChild('imagelink', $AMSETTING['imagelink']);
  $obj = $xml->addChild('enablecustomsettings', $AMSETTING['enablecustomsettings']);
  $obj = $xml->addChild('customsettings');
  $obj->addCData($AMSETTING['customsettings']);
  $obj = $xml->addChild('ver', AMVERSION);
  return @XMLsave($xml, AMSETTINGS);
}


/*******************************************************
 * @function am_generate_htaccess
 * @action generate a .htaccess sample config based on current settings
 */
function am_generate_htaccess() {
  global $AMPAGEURL, $PERMALINK;
  $path = tsl(suggest_site_path(true));
  $prefix = '';
  $page =  '';
  # format prefix and page directions
  if ($AMPAGEURL != 'index') {
    if ( am_get_parent() != '' && ($PERMALINK == '' || strpos($PERMALINK,'%parent%') !== false) ) {
      $prefix = am_get_parent().'/'.$AMPAGEURL.'/';
    } else {
      $prefix = $AMPAGEURL.'/';
    }
    $page = 'id='.$AMPAGEURL.'&';
  }
  # generate .htaccess contents
  $htaccess = file_get_contents(GSPLUGINPATH . 'article_manager/temp.htaccess');
  $htaccess = str_replace('**PATH**', $path, $htaccess);
  $htaccess = str_replace('**PREFIX**', $prefix, $htaccess);
  $htaccess = str_replace('**PAGE**', $page, $htaccess);
  $htaccess = htmlentities($htaccess, ENT_QUOTES, 'UTF-8');
  # show .htaccess
  include(AMTEMPLATEPATH . 'htaccess.php');
}


?>
