<?php if (!defined('IN_GS')) {die('you cannot load this page directly.');}

/**
 * Article Manager front-end functions.
 */


/*******************************************************
 * @function am_show_page
 * @param $index - page index (pagination)
 * @param $filter - if true, apply content filter
 * @action show posts on news page
 */
function am_show_page($index=AMFIRSTPAGE, $filter=true) {
  global $AMPOSTSPERPAGE, $amoption;
  $p1 = intval(AMFIRSTPAGE);
  $index = intval($index);
  $posts = am_get_posts();
  $pages = array_chunk($posts, intval($AMPOSTSPERPAGE), true);
  if ($index >= $p1 && $index-$p1 < sizeof($pages))
    $posts = $pages[$index-$p1];
  else
    $posts = array();
  if (!empty($posts)) {
    $showexcerpt = am_get_option('excerpt');
    if ($filter) ob_start();
    foreach ($posts as $post)
      am_show_post($post->slug, $showexcerpt, false);
    if (sizeof($pages) > 1 && am_get_option('shownav',true))
      am_show_navigation($index, sizeof($pages));
    if ($filter) echo am_ob_get_content(true);
  } else {
    echo '<p>' . i18n_r('article_manager/NO_POSTS') . '</p>';
  }
}


/*******************************************************
 * @function am_show_archive
 * @param $id - unique archive id
 * @param $filter - if true, apply content filter
 * @action show posts by archive
 * @return true if posts shown
 */
function am_show_archive($archive, $filter=true) {
  global $AMSETTING;
  $archives = am_get_archives($AMSETTING['archivesby']);
  if (array_key_exists($archive, $archives)) {
    $showexcerpt = am_get_option('excerpt');
    $posts = $archives[$archive];
    if ($filter) ob_start();
    foreach ($posts as $slug)
      am_show_post($slug, $showexcerpt, false);
    if ($filter) echo am_ob_get_content(true);
    return true;
  } else {
    return false;
  }
}


/*******************************************************
 * @function am_show_tag
 * @param $tag - unique tag id
 * @param $filter - if true, apply content filter
 * @action show posts by tag
 * @return true if posts shown
 */
function am_show_tag($tag, $filter=true) {
  $tag = am_lowercase_tags($tag);
  $tags = am_get_tags();
  if (array_key_exists($tag, $tags)) {
    $showexcerpt = am_get_option('excerpt');
    $posts = $tags[$tag];
    if ($filter) ob_start();
    foreach ($posts as $slug)
      am_show_post($slug, $showexcerpt, false);
    if ($filter) echo am_ob_get_content(true);
    return true;
  } else {
    return false;
  }
}

/*******************************************************
 * @function am_show_tag_page
 * @param $tag - unique tag id
 * @param $index - page index (pagination)
 * @param $filter - if true, apply content filter
 * @action show posts by tag with pagination
 * @return true if posts shown
 * @since 3.0
 */
function am_show_tag_page($tag, $index=AMFIRSTPAGE, $filter=true) {
  global $AMPOSTSPERPAGE;
  $tag = am_lowercase_tags($tag);
  $tags = am_get_tags();
  if (array_key_exists($tag, $tags)) {
    $showexcerpt = am_get_option('excerpt');
    $posts = $tags[$tag];
    $p1 = intval(AMFIRSTPAGE);
    $index = intval($index);
    $pages = array_chunk($posts, intval($AMPOSTSPERPAGE), true);
    if ($index >= $p1 && $index-$p1 < sizeof($pages)) {
      $posts = $pages[$index-$p1];
      if ($filter) ob_start();
      foreach ($posts as $slug)
        am_show_post($slug, $showexcerpt, false);
      if (sizeof($pages) > 1 && am_get_option('shownav',true))
        am_show_navigation($index, sizeof($pages), $tag);
      if ($filter) echo am_ob_get_content(true);
      return true;
    }
  }
  return false;
}


/*******************************************************
 * @function am_show_search_results()
 * @action search posts by keyword(s)
 */
function am_show_search_results() {
  $keywords = @explode(' ', $_POST['keywords']);
  $posts = am_get_posts();
  foreach ($keywords as $keyword) {
    $match = array();
    foreach ($posts as $post) {
      $data = getXML(AMPOSTPATH.$post->slug.'.xml');
      $content = $data->title . $data->content;
      if (stripos($content, $keyword) !== false)
        $match[] = $post;
    }
    $posts = $match;
  }
  if (!empty($posts)) {
    $showexcerpt = am_get_option('excerpt');
    echo '<p>' . i18n_r('article_manager/FOUND') . '</p>',PHP_EOL;
    foreach ($posts as $post)
      am_show_post($post->slug, $showexcerpt, false);
  } else {
    echo '<p>' . i18n_r('article_manager/NOT_FOUND') . '</p>',PHP_EOL;
  }
}

/*******************************************************
 * @function am_reset_options
 * @param $pagetype news page type, can be 'single', 'main', 'archive', 'tag', 'search' or empty
 * @action set default or specific layout values
 * @since 3.0
 */
function am_reset_options($pagetype='') {
  global $amoption, $AMSETTING, $AMSHOWEXCERPT;
  $amoption = array();
  
  # pre 3.0 default settings (plus readmore in common.php)
  if (defined('AM2COMPAT') && AM2COMPAT) {
    $amoption['breakwords'] = true;
    $amoption['titletag'] = false;
    $amoption['navoldnew'] = true;
    if (!defined('AMFIRSTPAGE')) define('AMFIRSTPAGE',0);
  }

  # full/excerpt, readmore
  if ($AMSHOWEXCERPT == 'Y' || in_array($pagetype, array('archive','search','tag'))) {
    $amoption['excerpt'] = true;
    if ($AMSETTING['readmore'] == 'R')
      $amoption['readmore'] = true;
    elseif ($AMSETTING['readmore'] == 'F')
      $amoption['readmore'] = 'a';
    else
      $amoption['readmore'] = false;
  } else {
    $amoption['excerpt'] = false; // full post
  }

  # title link
  $amoption['titlelink'] = ($AMSETTING['titlelink']=='Y' || ($AMSETTING['titlelink']=='P' && $pagetype != 'single'));

  # go back link
  if ($pagetype == 'single') {
    if ($AMSETTING['gobacklink'] == 'N')
      $amoption['gobacklink'] = false;
    elseif ($AMSETTING['gobacklink'] == 'M')
      $amoption['gobacklink'] = 'main';
    else
      $amoption['gobacklink'] = true;
  }

  # tag separator
  $amoption['tagseparator'] = ' ';

  # author
  $amoption['showauthor'] = false;
  $amoption['defaultauthor'] = '';

  # images
  if ( $AMSETTING['images'] == 'N'
    || ($pagetype == 'single' && $AMSETTING['images'] == 'P')
    || ($pagetype != 'main' && $AMSETTING['images'] == 'M') ) {
    $amoption['showimages'] = false;
  } else {
    $amoption['showimages'] = true;
  }
  $amoption['imagewidth'] = intval($AMSETTING['imagewidth']);
  $amoption['imageheight'] = intval($AMSETTING['imageheight']);
  $amoption['imagecrop'] = ($AMSETTING['imagecrop'] == '1');
  $amoption['imagealt'] = ($AMSETTING['imagealt'] == '1');
  $amoption['imagelink'] = ($pagetype != 'single' && $AMSETTING['imagelink'] == '1');
  $amoption['imagetitle'] = false;
  $amoption['imageexternal'] = false;
  $amoption['imagedefault'] = '';
  $amoption['imagesizeattr'] = false;

  # custom settings
  if ($AMSETTING['enablecustomsettings'] == '1') {
    # extract settings
    foreach(preg_split('~\R~', $AMSETTING['customsettings']) as $line) {
      $line = trim($line);
      if ($line && strpos($line,'#') !== 0 && strpos($line,'//') !== 0) { // exclude empty and commented lines
        $arr = explode(' ',preg_replace("/[[:blank:]]+/"," ",$line));
        if (count($arr) > 1) {
          if (in_array($arr[0], array('main','single','archive','tag','search')))
            $customsettings[$arr[0]][$arr[1]] = implode(' ',array_slice($arr,2));
          else
            $customsettings['default'][$arr[0]] = implode(' ',array_slice($arr,1));
        }
      }
    }
    # process settings and strings
    foreach(array('default', $pagetype) as $type) {
      if (isset($customsettings[$type])) {
        foreach($customsettings[$type] as $key=>$value) {
          if (substr($value,0,1) == '"' || substr($value,0,1) == "'") $value = substr($value,1,strlen($value)-2);
          if (strtoupper($key) == $key) {
            # language string
            am_set_text($key, $value);
          } else {
            # setting
            $amoption[strtolower($key)] = $value;
          }
        }
      }
    }
  }

  # html tags
  $amoption['markuppost'] = isset($amoption['markuppost']) ? str_replace(array('<','>'),'',$amoption['markuppost']) : 'div';
  $amoption['markuptitle'] = isset($amoption['markuptitle']) ? str_replace(array('<','>'),'',$amoption['markuptitle']) : 'h3';

  # fields
  if (isset($amoption['showfields'])) {
    $amoption['fields'] = explode(' ',preg_replace('/  +/', ' ',trim(str_replace(',',' ',$amoption['showfields']))));
  } else {
    $amoption['fields'] = array('title','date','author','image','content','tags');
  }

  # imagesize shorthand
  if (isset($amoption['imagesize'])) {
    if ($amoption['imagesize'] == 0 || $amoption['imagesize'] == 'full') {
      $amoption['imagewidth'] = 0;
      $amoption['imageheight'] = 0;
      $amoption['imagecrop'] = 0;
    } else {
      $imageparams = explode(' ',preg_replace('/  +/', ' ',trim(str_replace(',',' ',$amoption['imagesize']))));
      $amoption['imagewidth'] = isset($imageparams[0]) ? $imageparams[0] : 0;
      $amoption['imageheight'] = isset($imageparams[1]) ? $imageparams[1] : 0;
      $amoption['imagecrop'] = isset($imageparams[2]) ? $imageparams[2] : 0;
    }
  }

  # custom excerpt length
  if (isset($amoption['excerptlength'])) {
    global $AMEXCERPTLENGTH;
    $AMEXCERPTLENGTH = $amoption['excerptlength']; // workaround(*)
  }

  # more
  if (!isset($amoption['more'])) $amoption['more'] = false;

  # readmore
  if (!isset($amoption['readmore']))
    $amoption['readmore'] = false;
  else // custom setting - anything beginning with 'a' (all, Always, ...)
    if (strtolower($amoption['readmore'][0]) == 'a')
      $amoption['readmore'] = 'a';

  # tag pagination
  if (!isset($amoption['tagpagination'])) {
    $amoption['tagpagination'] = false;
  } else { // anything beginning with 'd' (Default, Dynamic...) or 'f' (Fancy, Folder...)
    $amoption['tagpagination'] = strtolower($amoption['tagpagination'][0]);
    if (!in_array($amoption['tagpagination'], array('d','f')))
      $amoption['tagpagination'] = false;
  }
}


/*******************************************************
 * @function am_show_post
 * @param $slug post slug
 * @param $showexcerpt - if TRUE, print only a short summary
 * @param $filter - if true, apply content filter
 * @param $single post page?
 * @action show the requested post on front-end news page, as defined by $amoption values
 * @return true if post exists
 */
function am_show_post($slug, $showexcerpt=false, $filter=true, $single=false) {
  global $amoption, $amdata;
  $file = AMPOSTPATH.$slug.'.xml';
  if (dirname(realpath($file)) == realpath(AMPOSTPATH)) // no path traversal
    $post = @getXML($file);
  if (!empty($post) && $post->private != 'Y') {
    $url     = am_get_url('post') . $slug;
    $title   = stripslashes($post->title);
    $date    = am_get_date(i18n_r('article_manager/DATE_FORMAT'), strtotime($post->date));
    $content = strip_decode($post->content);
    $image   = stripslashes($post->image);
    $tags = !empty($post->tags) ? explode(',', am_lowercase_tags(strip_decode($post->tags))) : array();

    # save post data?
    $amdata = ($single) ? compact('slug', 'url', 'title', 'content', 'image', 'tags') : array();

    if ($filter) ob_start();

    echo '  <',$amoption['markuppost'],' class="am_post';
    if ($single) echo ' am_post_single';
    echo '">',PHP_EOL;

    foreach ($amoption['fields'] as $field) {
      switch($field) {

        case 'title':
          echo '    <',$amoption['markuptitle'],' class="am_post_title">';
          if ($amoption['titlelink'])
            echo '<a href="',$url,'">',$title,'</a>';
          else
            echo $title;
          echo '</',$amoption['markuptitle'],'>',PHP_EOL;
          break;

        case 'date':
          echo '    <p class="am_post_date">',i18n_r('article_manager/PUBLISHED'),' ',$date,'</p>',PHP_EOL;
          break;

        case 'content':
          echo '    <div class="am_post_content">';
          if ($single) {
            echo $content;
          } else {
            $slice = '';
            $readmore = $amoption['readmore'];
            if ($amoption['more']) {
              $morepos = strpos($content, '<hr');
              if ($morepos !== false) {
                $slice = substr($content, 0, $morepos);
                if ($readmore)
                  $slice .= '      <p class="am_readmore"><a href="'.$url.'">'.i18n_r('article_manager/READ_MORE').'</a></p>'.PHP_EOL;
              }
            }
            if ($slice) {
              echo $slice;
            } else {
              if ($showexcerpt) {
                if (!$readmore)
                  echo am_create_excerpt($content);
                elseif ($readmore === 'a')
                  echo am_create_excerpt($content, $url, true);
                else
                  echo am_create_excerpt($content, $url);
              } else {
                echo $content;
                if ($readmore === 'a')
                  echo '      <p class="am_readmore"><a href="',$url,'">',i18n_r('article_manager/READ_MORE'),'</a></p>',PHP_EOL;
              }
            }
          }
          echo '    </div>',PHP_EOL;
          break;

        case 'tags':
          if ($tags) {
            echo '    <p class="am_post_meta"><b>' . i18n_r('article_manager/TAGS') . ':</b> ';
            $sep = '';
            foreach ($tags as $tag)
              if (substr($tag, 0, 1) != '_') {
                echo $sep,'<a href="',am_get_url('tag').rawurlencode($tag),'">',$tag,'</a>';
                if ($sep == '') $sep = $amoption['tagseparator'];
              }
            echo '</p>',PHP_EOL;
          }
          break;

        case 'image':
          $imageurl = $amoption['showimages'] ? am_get_image_url($image) : false;
          if ($imageurl) {
            $str = '';
            if (isset($amoption['imageclass']))
              $str .= ' class="'.$amoption['imageclass'].'"';
            if ($amoption['imagesizeattr'] && $amoption['imagewidth'] && $amoption['imageheight'])
              $str .= ' width="'.$amoption['imagewidth'].'" height="'.$amoption['imageheight'].'"';
            $str .= $amoption['imagealt']   ? ' alt="'.htmlspecialchars($title, ENT_COMPAT).'"' : ' alt=""';
            $str .= $amoption['imagetitle'] ? ' title="'.htmlspecialchars($title, ENT_COMPAT).'"' : '';
            $str = '<img src="'.htmlspecialchars($imageurl).'"'.$str.' />';
            if ($amoption['imagelink'])
              $str = '<a href="'.$url.'">'.$str.'</a>';
            echo '    <div class="am_post_image">',$str,'</div>',PHP_EOL;
          }
          break;

        case 'author':
          if ($amoption['showauthor']) {
            $author = stripslashes($post->author);
            if (empty($author) && $amoption['defaultauthor'])
              $author = $amoption['defaultauthor'];
            if (!empty($author))
                echo '    <p class="am_post_author">'.i18n_r('article_manager/AUTHOR').' <em>'.$author.'</em></p>'.PHP_EOL;
          }
          break;
      }
    }

    if (isset($amoption['componentbottompost'])) {
      get_component($amoption['componentbottompost']);
      echo PHP_EOL;
    }
    if ($single) {
      # show "go back" link?
      if ($amoption['gobacklink']) {
        $goback = ($amoption['gobacklink'] === 'main') ? am_get_url() : 'javascript:history.back()';
        echo '    <p class="am_post_back"><a href="'.$goback.'">';
        i18n('article_manager/GO_BACK');
        echo '</a></p>',PHP_EOL;
      }
    }

    echo '  </',$amoption['markuppost'],'>',PHP_EOL;

    if (isset($amoption['componentafterpost'])) {
      get_component($amoption['componentafterpost']);
      echo PHP_EOL;
    }
    
    if ($filter) echo am_ob_get_content(true);
    
    return true;
  } else {
    echo '<p>' . i18n_r('article_manager/NOT_EXIST') . '</p>',PHP_EOL;
    return false;
  }
}


/*******************************************************
 * @function am_show_navigation
 * @param $index - current page index
 * @param $total - total number of subpages
 * @param $tag - tag to filter by (optional)
 * @action provides links to navigate between subpages in main news or tag page
 */
function am_show_navigation($index, $total, $tag=null) {
  $p1 = intval(AMFIRSTPAGE);
  if (!$tag) {
    $first = am_get_url();
    $page = am_get_url('page');
  } else {
    $first = am_get_url('tag').rawurlencode($tag);
    if (am_get_option('tagpagination') == 'f')
      $page = $first.'/'.AMPARAMPAGE.'/';
    else
      $page = $first.'&amp;'.AMPARAMPAGE.'=';
  }
  echo '<div class="am_page_nav">';
  if (!am_get_option('navoldnew',false)) {
  
    $prevnext = am_get_option('navprevnext', '1');
    if (strtolower($prevnext[0]) == 'a') { // navPrevNext a[lways]
      $noPrev = '<span class="previous disabled">'.i18n_r('article_manager/PREV_TEXT').'</span>';
      $noNext = ' <span class="next disabled">'.i18n_r('article_manager/NEXT_TEXT').'</span>';
    } else {
      $noPrev = '';
      $noNext = '';
    }
      
    if ($prevnext && $index > $p1) {
      echo '<span class="previous"><a href="';
      echo $index > $p1+1 ? $page.($index-1) : $first;
      echo '" title="',i18n_r('article_manager/PREV_TITLE'),'">',i18n_r('article_manager/PREV_TEXT'),'</a></span>';
    } else {
      echo $noPrev;
    }
    
    if (am_get_option('navnumber',true)) {
      for ($i = 0; $i < $total; $i++) {
        if ($i+$p1 == $index) {
          echo ' <span class="current">',$i+1,'</span>';
        } else {
          echo ' <span><a href="';
          echo $i == 0 ? $first : $page.($i+$p1);
          echo '">',$i+1,'</a></span>';
        }
      }
    }
    
    if ($prevnext && $index < $total-1+$p1) {
      echo ' <span class="next"><a href="',$page.($index+1);
      echo '" title="',i18n_r('article_manager/NEXT_TITLE'),'">',i18n_r('article_manager/NEXT_TEXT'),'</a></span>';
    } else {
      echo $noNext;
    }
      
  } else {
  
  # Older/Newer navigation
    if ($index < $total-1+$p1) {
    ?>
    <div class="left">
      <a href="<?php echo $page.($index+1); ?>">
        <?php i18n('article_manager/OLDER_POSTS'); ?>
      </a>
    </div>
    <?php
    }
    if ($index > $p1) {
    ?>
    <div class="right">
      <a href="<?php echo ($index > $p1+1) ? $page.($index-1) : $first ?>">
        <?php i18n('article_manager/NEWER_POSTS'); ?>
      </a>
    </div>
    <?php
    }
  }
  echo '</div>';
}


/*******************************************************
 * @function am_post_title
 * @param $before Text to place before the title. Defaults to ''
 * @param $after Text to place after the title. Defaults to ''
 * @param $echo Display (true) or return (false)
 * @action Display or return the post title. Returns false if not on single post page
 * @since 2.3
 */
function am_post_title($before='', $after='', $echo=true) {
  global $amdata;
  if (isset($amdata['title']) && $amdata['title']) {
    $title = $before.$amdata['title'].$after;
    if ($echo) echo $title;
    return $title;
  } else {
    return false;
  }
}

/*******************************************************
 * @function am_post_slug
 * @param $echo Display (true) or return (false)
 * @action Display or return the post id (slug)
 * @return slug or false if not on single post page
 * @since 3.0
 */
function am_post_slug($echo=true) {
  global $amdata;
  if (isset($amdata['slug']) && $amdata['slug']) {
    $slug = $amdata['slug'];
    if ($echo) echo $slug;
    return $slug;
  } else {
    return false;
  }
}

/*******************************************************
 * @function am_post_url
 * @param $echo Display (true) or return (false)
 * @action Display or return the post URL
 * @return URL or false if not on single post page
 * @since 3.0
 */
function am_post_url($echo=true) {
  global $amdata;
  if (isset($amdata['url']) && $amdata['url']) {
    $url = $amdata['url'];
    if ($echo) echo $url;
    return $url;
  } else {
    return false;
  }
}

/*******************************************************
 * @function am_post_excerpt
 * @param $len Length or null for default length (settings)
 * @param $ellipsis Custom string for the ellipsis or null for default
 * @param $echo Display (true) or return (false)
 * @action Display or return a post excerpt
 * @return excerpt or empty string
 * @since 3.0
 */
function am_post_excerpt($len=null, $ellipsis=null, $echo=true) {
  global $amdata, $AMEXCERPTLENGTH, $amoption;
  if (isset($amdata['content']) && $amdata['content']) {
    if (!$len) $len = isset($amoption['excerptlength']) ? $amoption['excerptlength'] : $AMEXCERPTLENGTH; // workaround(*)
    if (!$ellipsis && $ellipsis !== '') $ellipsis = i18n_r('article_manager/ELLIPSIS');
    $excerpt = am_make_excerpt($amdata['content'], $len, $ellipsis);
    if ($echo) echo $excerpt;
    return $excerpt;
  } else {
    return '';
  }
}

/*******************************************************
 * @function am_post_image_url
 * @param $width or null for default width (settings)
 * @param $height or null for default height (settings)
 * @param $crop 0, 1, false or true, or null for default crop option (settings)
 * @param $default URL or filename of image if post has no image
 * @param $echo Display (true) or return (false)
 * @action Display or return post image URL
 * @return image URL or empty string
 * @since 3.0
 */
function am_post_image_url($width=null, $height=null, $crop=null, $default=null, $echo=true) {
  global $amdata;
  if (isset($amdata['image']) && $amdata['image']) {
    $url = htmlspecialchars(am_get_image_url($amdata['image'], $width, $height, $crop, $default));
    if ($echo) echo $url;
    return $url;
  } else {
    return '';
  }
}

/***
frontend functions, since 3.0
@todo: descriptions
 ***/

// conditionals

function am_is_site() {
  global $ampagetype;
  return in_array('site', $ampagetype);
}

function am_is_single() {
  global $ampagetype;
  return in_array('single', $ampagetype);
}

function am_is_main() {
  global $ampagetype;
  return in_array('main', $ampagetype);
}

function am_is_tag($tag=null) {
  global $ampagetype;
  if (in_array('tag', $ampagetype)) {
    if (!$tag)
      return true;
    else
      return (isset($_GET[AMPARAMTAG]) && $tag == rawurldecode($_GET[AMPARAMTAG]));
  }
}

function am_is_archive() {
  global $ampagetype;
  return in_array('archive', $ampagetype);
}

function am_is_search() {
  global $ampagetype;
  return in_array('search', $ampagetype);
}

function am_is_home() {
  global $ampagetype;
  return in_array('home', $ampagetype);
}

function am_post_has_image() {
  global $amdata;
  return (isset($amdata['image']) && $amdata['image']);
}

// check if single post has any tag or a certain tag
function am_post_has_tag($tag=null) {
  global $amdata;
  if ($amdata) {
    if (!isset($tag) && $amdata['tags'])
      return true;
    elseif (in_array($tag, $amdata['tags']))
      return true;
  }
  return false;
}

// set general option
function am_set_option($option, $value=true) {
  global $amoption;
  if ($option) $amoption[strtolower($option)] = $value;
}

// get option value, return $default if not defined
function am_get_option($option, $default=false) {
  global $amoption;
  if ($option) {
    $option = strtolower($option);
    if (isset($amoption[$option]))
      return $amoption[$option];
    else
      return $default;
  }
}

// images

function am_set_image_size($width=null, $height=null, $crop=false) {
  global $amoption;
  $amoption['imagewidth'] = $width;
  $amoption['imageheight'] = $height;
  $amoption['imagecrop'] = $crop;
}

// custom text/language strings

function am_set_text($i18nkey=null, $i18nvalue=null) {
  global $i18n;
  if ($i18nkey && $i18nvalue)
    $i18n['article_manager/'.$i18nkey] = $i18nvalue;
}


// patch for <title> tag
function am_update_page_title() {
  if (!am_is_single() || !am_get_option('titletag',true) || function_exists('amt_set_gstitle')) {
    return;
  } else {
    global $title, $ampagetitle;
    $ampagetitle = $title;
    $title = am_post_title('',' - '.$title,false);
  }
}

// restore original title - <title> tag patch
function am_restore_page_title() {
  if (!am_is_single() || !am_get_option('titletag',true) || function_exists('amt_set_gstitle')) {
    return;
  } else {
    global $title, $ampagetitle;
    $title = $ampagetitle;
  }
}

// get output buffer, optionally apply content filter
function am_ob_get_content($filter=true) {
	$output = ob_get_contents();
	ob_end_clean();
	if ($filter) {
		return exec_filter('content', $output);
	} else {
		return $output;
	}
}

?>